import {
  general_api_default
} from "./chunk-YT73QWCN.js";
import {
  getSearchEndpoint
} from "./chunk-ANB5BM5J.js";
import {
  getDeviceFilters
} from "./chunk-XXHONFSQ.js";
import {
  convertDeviceListStateToFilters
} from "./chunk-YETZPQFR.js";
import {
  commonErrorFallback,
  commonErrorHandler
} from "./chunk-2RJIDREZ.js";
import {
  actions_default
} from "./chunk-NNADGHSL.js";
import {
  actions,
  sliceName
} from "./chunk-UEP36GCI.js";
import {
  alertChannels,
  monitorApiUrlv1
} from "./chunk-A6CT6GTI.js";
import {
  headerNames
} from "./chunk-25AKG5HH.js";
import {
  DEVICE_LIST_DEFAULTS,
  TIMEOUTS
} from "./chunk-4B3IMP4I.js";

// src/monitorSlice/thunks.ts
import { createAsyncThunk } from "@reduxjs/toolkit";
var { page: defaultPage, perPage: defaultPerPage } = DEVICE_LIST_DEFAULTS;
var cutoffLength = 75;
var ellipsis = "...";
var longTextTrimmer = (text) => text.length >= cutoffLength + ellipsis.length ? `${text.substring(0, cutoffLength + ellipsis.length)}${ellipsis}` : text;
var sanitizeDeviceAlerts = (alerts) => alerts.map((alert) => ({ ...alert, fullName: alert.name, name: longTextTrimmer(alert.name) }));
var getDeviceAlerts = createAsyncThunk(`${sliceName}/getDeviceAlerts`, ({ id, config = {} }, { dispatch }) => {
  const { page = defaultPage, perPage = defaultPerPage, issuedBefore, issuedAfter, sortAscending = false } = config;
  const issued_after = issuedAfter ? `&issued_after=${issuedAfter}` : "";
  const issued_before = issuedBefore ? `&issued_before=${issuedBefore}` : "";
  return general_api_default.get(`${monitorApiUrlv1}/devices/${id}/alerts?page=${page}&per_page=${perPage}${issued_after}${issued_before}&sort_ascending=${sortAscending}`).catch((err) => commonErrorHandler(err, `Retrieving device alerts for device ${id} failed:`, dispatch)).then(
    (res) => Promise.all([
      dispatch(actions.receiveDeviceAlerts({ deviceId: id, alerts: sanitizeDeviceAlerts(res.data) })),
      dispatch(actions.setAlertListState({ total: Number(res.headers[headerNames.total]) }))
    ])
  );
});
var getLatestDeviceAlerts = createAsyncThunk(`${sliceName}/getLatestDeviceAlerts`, ({ id, config = {} }, { dispatch }) => {
  const { page = defaultPage, perPage = 10 } = config;
  return general_api_default.get(`${monitorApiUrlv1}/devices/${id}/alerts/latest?page=${page}&per_page=${perPage}`).catch((err) => commonErrorHandler(err, `Retrieving device alerts for device ${id} failed:`, dispatch)).then((res) => Promise.resolve(dispatch(actions.receiveLatestDeviceAlerts({ deviceId: id, alerts: sanitizeDeviceAlerts(res.data) }))));
});
var getIssueCountsByType = createAsyncThunk(`${sliceName}/getIssueCountsByType`, ({ type, options = {} }, { dispatch, getState }) => {
  const state = getState();
  const { filters = getDeviceFilters(state), group, status, ...remainder } = options;
  const { applicableFilters: nonMonitorFilters, filterTerms } = convertDeviceListStateToFilters({
    ...remainder,
    filters,
    group,
    offlineThreshold: state.app.offlineThreshold,
    selectedIssues: [type],
    status
  });
  return general_api_default.post(getSearchEndpoint(getState()), {
    page: 1,
    per_page: 1,
    filters: filterTerms,
    attributes: [{ scope: "identity", attribute: "status" }]
  }).catch((err) => commonErrorHandler(err, `Retrieving issue counts failed:`, dispatch, commonErrorFallback)).then((res) => {
    const total = nonMonitorFilters.length ? state.monitor.issueCounts.byType[type].total : Number(res.headers[headerNames.total]);
    const filtered = nonMonitorFilters.length ? Number(res.headers[headerNames.total]) : total;
    if (total === state.monitor.issueCounts.byType[type].total && filtered === state.monitor.issueCounts.byType[type].filtered) {
      return Promise.resolve();
    }
    return Promise.resolve(dispatch(actions.receiveDeviceIssueCounts({ counts: { filtered, total }, issueType: type })));
  });
});
var getDeviceMonitorConfig = createAsyncThunk(
  `${sliceName}/getDeviceMonitorConfig`,
  (id, { dispatch }) => general_api_default.get(`${monitorApiUrlv1}/devices/${id}/config`).catch((err) => commonErrorHandler(err, `Retrieving device monitor config for device ${id} failed:`, dispatch)).then(({ data }) => Promise.all([dispatch(actions_default.receivedDevice({ id, monitors: data }), Promise.resolve(data))]))
);
var changeNotificationSetting = createAsyncThunk(
  `${sliceName}/changeNotificationSetting`,
  ({ enabled, channel = alertChannels.email }, { dispatch }) => {
    return general_api_default.put(`${monitorApiUrlv1}/settings/global/channel/alerts/${channel}/status`, { enabled }).catch((err) => commonErrorHandler(err, `${enabled ? "En" : "Dis"}abling  ${channel} alerts failed:`, dispatch)).then(
      () => Promise.all([
        dispatch(actions.changeAlertChannel({ channel, enabled })),
        dispatch(actions_default.setSnackbar(`Successfully ${enabled ? "en" : "dis"}abled ${channel} alerts`, TIMEOUTS.fiveSeconds))
      ])
    );
  }
);

export {
  getDeviceAlerts,
  getLatestDeviceAlerts,
  getIssueCountsByType,
  getDeviceMonitorConfig,
  changeNotificationSetting
};
//# sourceMappingURL=chunk-NI4SZOCF.js.map